===
API
===

This is the documentation for the Python client API for eduVPN.

Remote calls
============

.. automodule:: eduvpn.remote
    :members:
    :undoc-members:
    :show-inheritance:


eduVPN OAuth2
=============

.. automodule:: eduvpn.oauth2
    :members:
    :undoc-members:
    :show-inheritance:


Crypto
======

.. automodule:: eduvpn.crypto
    :members:
    :undoc-members:
    :show-inheritance:


eduVPN IO
=========

.. automodule:: eduvpn.io
    :members:
    :undoc-members:
    :show-inheritance:


.. Network Manager wrapping
.. ========================
..
..
.. .. automodule:: eduvpn.manager
..     :members:
..     :undoc-members:
..     :show-inheritance:

OpenVPN
=======

.. automodule:: eduvpn.openvpn
    :members:
    :undoc-members:
    :show-inheritance:

.. Notifications
.. =============
..
.. .. automodule:: eduvpn.notify
..     :members:
..     :undoc-members:
..     :show-inheritance:
..
.. Utilities
.. =========
..
.. .. automodule:: eduvpn.util
..     :members:
..     :undoc-members:
..     :show-inheritance:

Exceptions
==========

.. automodule:: eduvpn.exceptions
    :members:
    :undoc-members:
    :show-inheritance: